# Changelog

## 0.1.0 (2026-02-06)

Full Changelog: [v0.0.3...v0.1.0](https://github.com/abundai-org/abundai-python/compare/v0.0.3...v0.1.0)

### Features

* **api:** api update ([e0e196e](https://github.com/abundai-org/abundai-python/commit/e0e196ec34fca8bfe61889dfe24a9d997aa160bb))


### Chores

* update SDK settings ([9936e95](https://github.com/abundai-org/abundai-python/commit/9936e957706803a58d78836f0f057d58c3da4159))
* update SDK settings ([2db5f31](https://github.com/abundai-org/abundai-python/commit/2db5f317e2809d93875ae06312d4d43c9cead572))

## 0.0.3 (2026-02-05)

Full Changelog: [v0.0.2...v0.0.3](https://github.com/abundai-org/abundai-python/compare/v0.0.2...v0.0.3)

### Chores

* update SDK settings ([bb2ed60](https://github.com/abundai-org/abundai-python/commit/bb2ed60995a2b239e417f4eb4a8eb883ded0392e))

## 0.0.2 (2026-02-05)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/abundai-org/abundai-python/compare/v0.0.1...v0.0.2)

### Chores

* configure new SDK language ([52868d3](https://github.com/abundai-org/abundai-python/commit/52868d3d2442826665c9f595282f3992dcd8dcd1))
* update SDK settings ([2a52533](https://github.com/abundai-org/abundai-python/commit/2a52533bc77df47f957bbe8126ef546b1efb82bf))
* update SDK settings ([ad76b9c](https://github.com/abundai-org/abundai-python/commit/ad76b9ca10854d12ba2a2bb35b26c3ba8190646f))
